#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-parse
version:              0.2.1.1
visibility:           public
id:                   conduit-parse-0.2.1.1-CKuqKlc3rRYDAI166kSh5i
key:                  conduit-parse-0.2.1.1-CKuqKlc3rRYDAI166kSh5i
license:              LicenseRef-PublicDomain
maintainer:           koral <koral@mailoo.org>
author:               koral <koral@mailoo.org>
homepage:             https://github.com/k0ral/conduit-parse
synopsis:             Parsing framework based on conduit.
description:          Please refer to README.
category:             Conduit, Text
abi:                  d57f977ba0b3cbf952faf416ff8deaef
exposed:              True
exposed-modules:      Data.Conduit.Parser
hidden-modules:       Data.Conduit.Parser.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/conduit-parse-0.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/conduit-parse-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/conduit-parse-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-parse
hs-libraries:         HSconduit-parse-0.2.1.1-CKuqKlc3rRYDAI166kSh5i
depends:
    base-4.18.2.1 conduit-1.3.6.1-534uwm1BQ035a3x29nwuhR
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO mtl-2.3.1
    parsers-0.12.12-IEaPsqFzCYyC5PgjDXgLBm
    safe-0.3.21-Hishw766JFf9X5XLYDU9sV
    safe-exceptions-0.1.7.4-LZv8NFJplAmBopXPxrgiz2 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-conduit-parse/html/conduit-parse.haddock

haddock-html:         /usr/share/doc/haskell-conduit-parse/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

